##  Modeling Major IT Systems
Modeling complex IT systems can be challenging. We provide examples that can serve as a starting point and help accelerate the process of adding your major IT systems in SAP LeanIX. Additionally, you will get an overview of how to model Software-as-a-Service (SaaS), Platform-as-a-Service (PaaS), and Infrastructure-as-a-Service (IaaS) models in SAP LeanIX.
You will find our modeling best practices for major IT systems such as [SAP](https://help.sap.com/docs/leanix/ea/sap-modeling-best-practices?locale=en-US&state=PRODUCTION&version=CLOUD "This modeling guide offers best practices for modeling SAP Cloud Solutions like S/4HANA and SAP BTP alongside legacy systems like SAP ERP 6.0."), [Microsoft](https://help.sap.com/docs/leanix/ea/microsoft-applications-modeling-best-practices?locale=en-US&state=PRODUCTION&version=CLOUD "This modeling guide offers best practices for modeling Microsoft solutions like Microsoft Azure, Microsoft Dynamics, and Microsoft Office 365."), [Google](https://help.sap.com/docs/leanix/ea/google-cloud-platform-modeling-best-practices?locale=en-US&state=PRODUCTION&version=CLOUD "This modeling guide offers best practices for modeling the services of the Google Cloud Platform \(GCP\) as an IaaS solution."), [Salesforce](https://help.sap.com/docs/leanix/ea/salesforce-applications-modeling-best-practices?locale=en-US&state=PRODUCTION&version=CLOUD "This modeling guide offers best practices for modeling Salesforce as a SaaS and a PaaS solution."), and [AWS](https://help.sap.com/docs/leanix/ea/aws-applications-modeling-best-practices?locale=en-US&state=PRODUCTION&version=CLOUD "This modeling guide offers best practices for modeling Amazon Web Services \(AWS\).").
Please note that your own models may differ from our best practice examples. This could be due to industry-specific Business Capabilities and the required degree of granularity in Technology Stacks.
